@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 ################################################################################
-#  Copyright (C) 2012-2013  Travis Shirk <travis@pobox.com>
+#  Copyright (C) 2012-2015  Travis Shirk <travis@pobox.com>
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 ################################################################################
 import re
 from collections import namedtuple
-import logging
 
 from .. import core
 from ..utils import requireUnicode
@@ -31,7 +30,8 @@ from . import (LATIN1_ENCODING, UTF_8_ENCODING, UTF_16BE_ENCODING,
 from .headers import FrameHeader
 
 
-log = logging.getLogger(__name__)
+from ..utils.log import getLogger
+log = getLogger(__name__)
 
 
 class FrameException(Error):
@@ -104,6 +104,9 @@ class Frame(object):
     def render(self):
         return self._assembleFrame(self.data)
 
+    def __lt__(self, other):
+        return self.id < other.id
+
     @staticmethod
     def decompress(data):
         import zlib
@@ -499,7 +502,7 @@ class ImageFrame(Frame):
     MIN_TYPE            = OTHER
     MAX_TYPE            = PUBLISHER_LOGO
 
-    URL_MIME_TYPE       = "-->"
+    URL_MIME_TYPE       = b"-->"
 
     @requireUnicode("description")
     def __init__(self, id=IMAGE_FID, description=u"",
@@ -523,6 +526,15 @@ class ImageFrame(Frame):
     def description(self, d):
         self._description = d
 
+    @property
+    def mime_type(self):
+        return self._mime_type
+
+    @mime_type.setter
+    def mime_type(self, m):
+        m = m or b''
+        self._mime_type = m if isinstance(m, BytesType) else m.encode('ascii')
+
     @property
     def picture_type(self):
         return self._pic_type
@@ -542,7 +554,7 @@ class ImageFrame(Frame):
         self.encoding = encoding = input.read(1)
 
         # Mime type
-        self.mime_type = ""
+        self.mime_type = b""
         if frame_header.minor_version != 2:
             ch = input.read(1)
             while ch and ch != b"\x00":
@@ -556,8 +568,8 @@ class ImageFrame(Frame):
             core.parseError(FrameException("APIC frame does not contain a mime "
                                            "type"))
         if (self.mime_type != self.URL_MIME_TYPE and
-                self.mime_type.find("/") == -1):
-            self.mime_type = "image/" + self.mime_type
+                self.mime_type.find(b"/") == -1):
+            self.mime_type = b"image/" + self.mime_type
 
         pt = ord(input.read(1))
         log.debug("Initial APIC picture type: %d" % pt)
@@ -600,7 +612,14 @@ class ImageFrame(Frame):
                                            "data/url"))
 
     def render(self):
-        self._initEncoding()
+        # some code has problems with image descriptions encoded <> latin1
+        # namely mp3diags: work around the problem by forcing latin1 encoding for 
+        # empty descriptions, which is by far the most common case anyway
+        if self.description:
+            self._initEncoding()
+        else:
+            self.encoding = LATIN1_ENCODING
+
         if not self.image_data and self.image_url:
             self.mime_type = self.URL_MIME_TYPE
 
